@@ -360,7 +360,11 @@ return(outC)
 
 .plusm <- function(e1, e2, Dclass = "DiscreteDistribution"){
             if (length(e2)>1) stop("length of operator must be 1")
-            if (isTRUE(all.equal(e2, 0, check.attributes = FALSE))) return(e1)
+            if (.isEqual(e2, 0)) return(e1)
+
+            if(Dclass %in% c("AffLinDiscreteDistribution",
+                              "AffLinAbscontDistribution"))
+               if(.isEqual(e1@a,1)&&.isEqual(e1@b+e2,0)) return(e1@X0)
 
             if ((Dclass == "DiscreteDistribution")||
                 (Dclass == "AffLinDiscreteDistribution"))
@@ -412,9 +416,12 @@ return(outC)
 .multm <- function(e1, e2, Dclass = "DiscreteDistribution"){
             if (length(e2)>1) stop("length of operator must be 1")
 
-            if (isTRUE(all.equal(e2, 1, check.attributes = FALSE))) return(e1)
-            if (isTRUE(all.equal(e2, 0, check.attributes = FALSE)))
-               return(new("Dirac", location = 0))
+            if (.isEqual(e2, 1)) return(e1)
+            if (.isEqual(e2, 0))  return(new("Dirac", location = 0))
+
+            if(Dclass %in% c("AffLinDiscreteDistribution",
+                              "AffLinAbscontDistribution"))
+               if(.isEqual(e1@a*e2,1)&&.isEqual(e1@b,0)) return(e1@X0)
 
             rnew <- function(n, ...){}
             body(rnew) <- substitute({ f(n, ...) * g },
@@ -425,9 +432,10 @@ return(outC)
                  if (e2 < 0) supportnew <- rev(supportnew)
 
                  coR <- substitute({
-                             owarn <- getOption("warn"); options(warn = -1)
+                             o.warn <- getOption("warn"); options(warn = -1)
+                             on.exit(options(warn=o.warn))
                              d0 <- object@d(x = q / e2C)
-                             options(warn = owarn)
+                             options(warn = o.warn)
                              if (!lower.tail) d0 <- -d0
                              p0 <- p0 + d0},
                              list(e2C = e2)
@@ -452,9 +460,10 @@ return(outC)
                  if (e2 < 0) supportnew <- rev(supportnew)
 
                  coR <- substitute({
-                             owarn <- getOption("warn"); options(warn = -1)
+                             o.warn <- getOption("warn"); options(warn = -1)
+                             on.exit(options(warn=o.warn))
                              d0 <- object@d(x = q / e2C)
-                             options(warn = owarn)
+                             options(warn = o.warn)
                              if (!lower.tail) d0 <- -d0
                              p0 <- p0 + d0},
                              list(e2C = e2)
@@ -719,7 +728,8 @@ return(f)
 
 .makeQNew <- function(x, px.l, px.u, notwithLLarg = FALSE, yL , yR,
                       Cont = TRUE){
-  owarn <- getOption("warn"); options(warn = -1)
+  o.warn <- getOption("warn"); options(warn = -1)
+  on.exit(options(warn=o.warn))
   mfun <- if (Cont) .makeQc else
           .makeQd
   ix <- .isEqual01(px.l)
@@ -742,7 +752,7 @@ return(f)
          rm(xx,yy)
      ifElseQS <- quote(if (lower.tail) q.l(p01) else q.u(p01))
   }
-  options(warn = owarn)
+  options(warn = o.warn)
   qfun <- function(p, lower.tail = TRUE, log.p = FALSE){}
   body(qfun) <- substitute({
           if (log.p) p <- exp(p)
@@ -798,10 +808,26 @@ return(f)
             rnew <- function(n, ...){}
             body(rnew) <- substitute({ exp(f(n, ...)) },
                                          list(f = e1@r))
-            dnew <- .makeD(substitute(e1, list(e1 = e1)),
-                           substitute(alist(x = log(x*(x>0)+(x<=0)))),
-                           stand = substitute(x+(x==0)),
-                           fac = substitute((x>0)))
+                                    
+            
+            dnew0 <- .makeD(substitute(e1, list(e1 = e1)),
+                            substitute(alist(x = log(x*(x>0)+(x<=0)))),
+                            stand = substitute(x+(x==0)),
+                            fac = substitute((x>0)))
+
+            # extrapolation for x=0
+            x0a <- 10^(-(1:10)/4) 
+            f0a <- dnew0(x = x0a, log = FALSE)
+            f0  <- max(spline(x0a,f0a, xout = 0)$y,0)
+            lf0 <- log(f0)
+
+            dnew <- function(x, log = FALSE, ...){
+               d0 <- dnew0(x, log = log, ...)
+               i0 <- .isEqual(x,0)
+               if(!any(i0)) return(d0)
+               if(log) d0[i0] <- lf0 else d0[i0] <- f0
+               return(d0)
+            }
             pnew <- .makeP(substitute(e1, list(e1 = e1)),
                            substitute(alist(q = log(q*(q>0)+(q<=0)))),
                            fac = substitute((q>0)),
